@@ -10,21 +10,6 @@ class AmazingRibs(AbstractScraper):
     def host(cls):
         return "amazingribs.com"
 
-    def author(self):
-        return self.schema.author()
-
-    def title(self):
-        return self.schema.title()
-
-    def total_time(self):
-        return self.schema.total_time()
-
-    def yields(self):
-        return self.schema.yields()
-
-    def ingredients(self):
-        return self.schema.ingredients()
-
     def ingredient_groups(self):
         return group_ingredients(
             self.ingredients(),
@@ -33,9 +18,6 @@ class AmazingRibs(AbstractScraper):
             ".wprm-recipe-ingredients li",
         )
 
-    def instructions(self):
-        return self.schema.instructions()
-
     def equipment(self):
         equipment_items = [
             normalize_string(e.get_text())
