@@ -13,18 +13,6 @@ class BareFootContessa(AbstractScraper):
     def author(self):
         return "Ina Garten"
 
-    def title(self):
-        return self.schema.title()
-
-    def category(self):
-        return self.schema.category()
-
-    def yields(self):
-        return self.schema.yields()
-
-    def image(self):
-        return self.schema.image()
-
     def ingredients(self):
         ingredient_list = []
         ingredient_divs = self.soup.find_all("div", {"class": "mb-10"})
