@@ -11,12 +11,6 @@ class BBCFood(AbstractScraper):
     def title(self):
         return normalize_string(self.soup.find("h1").get_text())
 
-    def total_time(self):
-        return self.schema.total_time()
-
-    def yields(self):
-        return self.schema.yields()
-
     def author(self):
         container = self.soup.find("div", {"class": "chef__name"})
         if not container:
@@ -24,9 +18,3 @@ class BBCFood(AbstractScraper):
 
         author = container.a
         return author.text if author else None
-
-    def image(self):
-        return self.schema.image()
-
-    def ingredients(self):
-        return self.schema.ingredients()
