@@ -9,21 +9,6 @@ class BudgetBytes(AbstractScraper):
     def host(cls):
         return "budgetbytes.com"
 
-    def title(self):
-        return self.schema.title()
-
-    def author(self):
-        return self.schema.author()
-
-    def total_time(self):
-        return self.schema.total_time()
-
-    def yields(self):
-        return self.schema.yields()
-
-    def ingredients(self):
-        return self.schema.ingredients()
-
     def ingredient_groups(self):
         return group_ingredients(
             self.ingredients(),
@@ -32,12 +17,6 @@ class BudgetBytes(AbstractScraper):
             ".wprm-recipe-ingredient",
         )
 
-    def instructions(self):
-        return self.schema.instructions()
-
-    def ratings(self):
-        return self.schema.ratings()
-
     def equipment(self):
         equipment_items = [
             link.get_text()
