@@ -15,21 +15,6 @@ class CookingCircle(AbstractScraper):
             .get_text()
         )
 
-    def title(self):
-        return self.schema.title()
-
-    def category(self):
-        return self.schema.category()
-
-    def total_time(self):
-        return self.schema.total_time()
-
-    def yields(self):
-        return self.schema.yields()
-
-    def image(self):
-        return self.schema.image()
-
     def ingredients(self):
         ul_list = (
             self.soup.find(
