@@ -12,24 +12,9 @@ class EatWell101(AbstractScraper):
     def host(cls):
         return "eatwell101.com"
 
-    def author(self):
-        return self.schema.author()
-
-    def title(self):
-        return self.schema.title()
-
     def category(self):
         return html.unescape(self.schema.category())
 
-    def total_time(self):
-        return self.schema.total_time()
-
-    def yields(self):
-        return self.schema.yields()
-
-    def image(self):
-        return self.schema.image()
-
     def ingredients(self):
         ingredients_h2 = self.soup.find(
             "h2", string=re.compile(r"Ingredients", re.IGNORECASE)
@@ -57,8 +42,5 @@ class EatWell101(AbstractScraper):
 
         return "\n".join(instructions_list)
 
-    def cuisine(self):
-        return self.schema.cuisine()
-
     def description(self):
         return self.soup.find("div", {"class": "saveurteaser"}).get_text()
