@@ -9,21 +9,6 @@ class Maangchi(AbstractScraper):
     def host(cls):
         return "maangchi.com"
 
-    def author(self):
-        return self.schema.author()
-
-    def title(self):
-        return self.schema.title()
-
-    def category(self):
-        return self.schema.category()
-
-    def yields(self):
-        return self.schema.yields()
-
-    def image(self):
-        return self.schema.image()
-
     def ingredients(self):
         before = self.soup.find("h2", string="Ingredients").find_all_next("li")
         after = self.soup.find("h2", string="Directions").find_all_previous("li")
@@ -40,12 +25,3 @@ class Maangchi(AbstractScraper):
         return "\n".join(
             [normalize_string(instruction.get_text()) for instruction in instructions]
         )
-
-    def ratings(self):
-        return self.schema.ratings()
-
-    def cuisine(self):
-        return self.schema.cuisine()
-
-    def description(self):
-        return self.schema.description()
