@@ -8,18 +8,6 @@ class NibbleDish(AbstractScraper):
     def host(cls):
         return "nibbledish.com"
 
-    def title(self):
-        return self.schema.title()
-
-    def total_time(self):
-        return self.schema.total_time()
-
-    def yields(self):
-        return self.schema.yields()
-
-    def image(self):
-        return self.schema.image()
-
     def ingredients(self):
         schema_ingredients = self.schema.ingredients()
 
@@ -49,6 +37,3 @@ class NibbleDish(AbstractScraper):
         return "\n".join(
             [normalize_string(instruction.get_text()) for instruction in instructions]
         )
-
-    def ratings(self):
-        return self.schema.ratings()
