@@ -17,24 +17,12 @@ class NRKMat(AbstractScraper):
             .replace("Kilde: ", "")
         )
 
-    def title(self):
-        return self.schema.title()
-
-    def category(self):
-        return self.schema.category()
-
     def yields(self):
         try:
             return self.schema.yields()
         except SchemaOrgException:
             return None
 
-    def image(self):
-        return self.schema.image()
-
-    def ingredients(self):
-        return self.schema.ingredients()
-
     def ingredient_groups(self):
         return group_ingredients(
             self.ingredients(),
@@ -42,9 +30,3 @@ class NRKMat(AbstractScraper):
             "h4.recipe-meta-title",
             "ul.recipe-list:not(.recipe-list-meta) > li",
         )
-
-    def instructions(self):
-        return self.schema.instructions()
-
-    def description(self):
-        return self.schema.description()
