@@ -8,14 +8,11 @@ class OwenHan(AbstractScraper):
         return "owen-han.com"
 
     def author(self):
-        return self.schema.author()
+        return self.soup.find("span", {"class": "author-name"}).get_text()
 
     def title(self):
         return self.soup.find("h1", {"class": "entry-title"}).text
 
-    def image(self):
-        return self.schema.image()
-
     def ingredients(self):
         return [x for x in map(lambda x: x.text, self.soup.select("ul > li"))]
 
