@@ -9,15 +9,6 @@ class Przepisy(AbstractScraper):
     def host(cls):
         return "przepisy.pl"
 
-    def title(self):
-        return self.schema.title()
-
-    def author(self):
-        return self.schema.author()
-
-    def total_time(self):
-        return self.schema.total_time()
-
     def yields(self):
         return get_yields(self.soup.find("div", {"class": "person-count"}))
 
@@ -28,6 +19,3 @@ class Przepisy(AbstractScraper):
             normalize_string(i.get_text()) + " " + normalize_string(j.get_text())
             for i, j in zip(ingredients[0::2], ingredients[1::2])
         ]
-
-    def instructions(self):
-        return self.schema.instructions()
