@@ -12,24 +12,6 @@ class Rezeptwelt(AbstractScraper):
     def author(self):
         return normalize_string(self.soup.find("span", {"id": "viewRecipeAuthor"}).text)
 
-    def title(self):
-        return self.schema.title()
-
-    def category(self):
-        return self.schema.category()
-
-    def total_time(self):
-        return self.schema.total_time()
-
-    def yields(self):
-        return self.schema.yields()
-
-    def image(self):
-        return self.schema.image()
-
-    def ingredients(self):
-        return self.schema.ingredients()
-
     def instructions(self):
         container = self.soup.find("div", id="preparationSteps").find(
             "span", itemprop="text"
@@ -39,9 +21,6 @@ class Rezeptwelt(AbstractScraper):
         ]
         return "\n".join(filter(None, instructions))
 
-    def ratings(self):
-        return self.schema.ratings()
-
     def cuisine(self):
         try:
             return self.schema.cuisine()
